@@ -198,10 +198,10 @@ rarefit <- function(y, X, A = NULL, Q = NULL, hc, intercept = T, lambda = NULL,
                     nlam = 50, lam.min.ratio = 1e-4, nalpha = 10,
                     rho = 1e-2, eps1 = 1e-6, eps2 = 1e-5, maxite = 1e6) {
   if (is.null(A)) {
-    if (class(hc) != "hclust") stop("The tree needs to be an hclust object.")
+    if(!inherits(hc, "hclust")) stop("The tree needs to be an hclust object.")
     A <- tree.matrix(hc)
   } else {
-    if (class(A) != "dgCMatrix") stop("A is not in sparse matrix format.")
+    if(!inherits(A, "dgCMatrix")) stop("A is not in sparse matrix format.")
   }
   n <- nrow(X)
   p <- ncol(X)
